==> wyvern-2.2.7.tar.bz2: wyvern-2.2.7/lib/wc.h <==
/*****************************************************************************
 *
 * FILE:	wc.h
 * DESCRIPTION:	Wyvern: cache library header file
 * DATE:	Sun, Jun 29 2003
 * UPDATED:	Sun, Feb 26 2006
 * AUTHOR:	Kouichi ABE (WALL) / 
 * E-MAIL:	kouichi@MysticWALL.COM
 * URL:		http://www.MysticWALL.COM/
 * COPYRIGHT:	(c) 2003-2006 졿Kouichi ABE (WALL), All rights reserved.
 * LICENSE:
 *
 *  Copyright (c) 2003-2006 Kouichi ABE (WALL) <kouichi@MysticWALL.COM>,
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *   ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *   OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *   HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *   SUCH DAMAGE.
 *
 * $Id: wc.h,v 1.11 2006/02/25 22:49:52 kouichi Exp $
 *
 *****************************************************************************/

#ifndef	_WC_H
#define	_WC_H

#include <sys/types.h>

/******************************************************************************
 *
 *	Macros and structures definition
 *
 *****************************************************************************/

/*
 * Numeric release version identifier:
 * MNNFFPPS: major minor fix patch status
 * The status nibble has one of the values 0 for development,
 * 1 to e for betas 1 to 14, and f for release.
 * The patch level is exactly that.
 */
#define	WCL_VERSION_NUMBER	0x10000010L
#define	WCL_VERSION		"WCL/1.0.0"
#define	WCL_VERSION_TEXT	WCL_VERSION " (2006/02/26)"
#define	WCL_VERSION_TEXT_LONG	"Wyvern Cache Library 1.0.0, Sun, Feb 26 2006"

/* cache structure */
typedef struct _Cache {
  struct _Cache *	next;
  struct _Cache *	prev;
  void *		data;
} Cache;

/*****************************************************************************
 *
 *	Global function declaration
 *
 *****************************************************************************/

/* cache.c */
extern Cache *	wc_new_cache(size_t);
extern void	wc_insert_cache(Cache *, Cache *);
extern Cache *	wc_remove_cache(Cache *);
extern void *	wc_search_cache(Cache *, void *,
				int (*)(const void *, const void *));
extern void	wc_flush_cache(Cache *, void (*)(const void *));

#endif	/* _WC_H */

==> wyvern-2.2.10.tar.bz2: wyvern-2.2.10/lib/wc.h <==
/*****************************************************************************
 *
 * FILE:	wc.h
 * DESCRIPTION:	Wyvern: cache library header file
 * DATE:	Sun, Jun 29 2003
 * UPDATED:	Sun, Aug 19 2007
 * AUTHOR:	Kouichi ABE (WALL) / 
 * E-MAIL:	kouichi@MysticWALL.COM
 * URL:		http://www.MysticWALL.COM/
 * COPYRIGHT:	(c) 2003-2007 졿Kouichi ABE (WALL), All rights reserved.
 * LICENSE:
 *
 *  Copyright (c) 2003-2007 Kouichi ABE (WALL) <kouichi@MysticWALL.COM>,
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *   ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *   OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *   HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *   SUCH DAMAGE.
 *
 * $Id: wc.h,v 1.12 2007/08/19 05:57:22 kouichi Exp $
 *
 *****************************************************************************/

#ifndef	_WC_H
#define	_WC_H

#include <sys/types.h>

/******************************************************************************
 *
 *	Macros and structures definition
 *
 *****************************************************************************/

/*
 * Numeric release version identifier:
 * MNNFFPPS: major minor fix patch status
 * The status nibble has one of the values 0 for development,
 * 1 to e for betas 1 to 14, and f for release.
 * The patch level is exactly that.
 */
#define	WCL_VERSION_NUMBER	0x10000020L
#define	WCL_VERSION		"WCL/1.0.0"
#define	WCL_VERSION_TEXT	WCL_VERSION " (2007/08/19)"
#define	WCL_VERSION_TEXT_LONG	"Wyvern Cache Library 1.0.0, Sun, Aug 19 2007"

/* cache structure */
typedef struct _Cache {
  struct _Cache *	next;
  struct _Cache *	prev;
  void *		data;
} Cache;

/*****************************************************************************
 *
 *	Global function declaration
 *
 *****************************************************************************/

/* cache.c */
extern Cache *	wc_new_cache(size_t);
extern void	wc_insert_cache(Cache *, Cache *);
extern Cache *	wc_remove_cache(Cache *);
extern void *	wc_search_cache(Cache *, void *,
				int (*)(const void *, const void *));
extern void	wc_flush_cache(Cache *, void (*)(const void *));

#endif	/* _WC_H */
